# ECG-featurizer
A python package for deriving features from ECGs


.. image:: https://readthedocs.org/projects/ECG-featurizer/badge/?version=latest
   :target: https://ECG-featurizer.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status


.. image:: https://travis-ci.org/ECG-featurizer/ECG-featurizer.svg?branch=master
   :target: https://travis-ci.org/ECG-featurizer/ECG-featurizer

.. image:: https://coveralls.io/repos/github/ECG-featurizer/ECG-featurizer/badge.svg?branch=master
   :target: https://coveralls.io/github/ECG-featurizer/ECG-featurizer?branch=master